@@ -43,6 +43,15 @@ def add_bban_checksum(country_code: str, bban: str) -> str:
     if country_code == "IT":
         checksum = algorithms["IT:default"].compute(bban[1:])
         bban = checksum + bban[1:]
+    elif country_code == "BE":
+        # The Belgian BBAN format is XXXYYYYYYYZZ where:
+        # - XXX: bank code
+        # - YYYYYYY: account number
+        # - ZZ: mod 97 remainder of XXYYYYYYY
+        # The bban passed to this function has this format XXX00YYYYY
+        bban = bban[:3] + bban[5:]
+        checksum = algorithms["BE:default"].compute(bban)
+        bban = bban + checksum
     return bban
 
 
@@ -121,6 +130,10 @@ class IBAN(common.Base):
         .. versionchanged:: 2020.08.3
             Added the `branch_code` parameter to allow the branch code (or sort code) to be
             specified independently.
+
+        .. versionchanged:: 2021.05.2
+            Added support for generating the country specific checksum of the BBAN for Belgian
+            banks.
         """
         spec: Dict = _get_iban_spec(country_code)
         bank_code_length: int = code_length(spec, "bank_code")
