@@ -16,6 +16,10 @@ def process():
 
     for row in list(sheet.get_rows())[4:]:
         bic, bank_code, name = row[:3]
+
+        if not any((bic, bank_code, name)):
+            continue
+
         registry.append(
             {
                 "country_code": "NL",
